You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ki...@apache.org on 2013/07/31 00:48:08 UTC

svn commit: r1508677 [3/9] - in /commons/proper/functor/trunk: api/src/main/java/org/apache/commons/functor/ core/src/main/java/org/apache/commons/functor/adapter/ core/src/main/java/org/apache/commons/functor/aggregator/ core/src/main/java/org/apache/...

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMeanValueAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMeanValueAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMeanValueAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMeanValueAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -18,14 +18,14 @@ package org.apache.commons.functor.aggre
 
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
  * {@link org.apache.commons.functor.aggregator.AbstractListBackedAggregator}
  * which computes the arithmetic mean of all the numbers in the list.
  */
-public final class DoubleMeanValueAggregatorFunction implements UnaryFunction<List<Double>, Double> {
+public final class DoubleMeanValueAggregatorFunction implements Function<List<Double>, Double> {
     /**
      * Does the actual computation and returns the result. Please note that
      * caller is responsible for synchronizing access to the list.

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMedianValueAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMedianValueAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMedianValueAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleMedianValueAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
@@ -28,7 +28,7 @@ import org.apache.commons.functor.UnaryF
  * which computes the <a href="http://en.wikipedia.org/wiki/Median">median</a>
  * of all the numbers in the list.
  */
-public final class DoubleMedianValueAggregatorFunction implements UnaryFunction<List<Double>, Double> {
+public final class DoubleMedianValueAggregatorFunction implements Function<List<Double>, Double> {
     /**
      * Flag to indicate whether we are going to operate on a copy of the list
      * given or not. In order to compute the median, we need to sort the list

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoublePercentileAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoublePercentileAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoublePercentileAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoublePercentileAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
@@ -31,7 +31,7 @@ import org.apache.commons.functor.UnaryF
  * using formula: <code>n = round((P / 100) * N + 0.5)</code> where N is the
  * number of items in a list.
  */
-public class DoublePercentileAggregatorFunction implements UnaryFunction<List<Double>, Double> {
+public class DoublePercentileAggregatorFunction implements Function<List<Double>, Double> {
     /** A percentile goes from 0 to 100% and that's it. */
     private static final double MAX_PERCENTAGE = 100.0;
     /**

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleSumAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleSumAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleSumAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/DoubleSumAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -18,14 +18,14 @@ package org.apache.commons.functor.aggre
 
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
  * {@link org.apache.commons.functor.aggregator.AbstractListBackedAggregator}
  * which sums up all the numbers in the list.
  */
-public final class DoubleSumAggregatorFunction implements UnaryFunction<List<Double>, Double> {
+public final class DoubleSumAggregatorFunction implements Function<List<Double>, Double> {
     /**
      * Does the actual adding and returns the result. Please note that caller is
      * responsible for synchronizing access to the list.

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMaxAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMaxAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMaxAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMaxAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -18,7 +18,7 @@ package org.apache.commons.functor.aggre
 
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
@@ -26,7 +26,7 @@ import org.apache.commons.functor.UnaryF
  * which finds the maximum number in a list. It does this by traversing the list
  * (once) -- so the complexity of this will be <i>O(n)</i>.
  */
-public class IntegerMaxAggregatorFunction implements UnaryFunction<List<Integer>, Integer> {
+public class IntegerMaxAggregatorFunction implements Function<List<Integer>, Integer> {
     /**
      * Does the actual traversal of the list and finds the maximum value then
      * returns the result. Please note that caller is responsible for

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMeanValueAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMeanValueAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMeanValueAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMeanValueAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -18,14 +18,14 @@ package org.apache.commons.functor.aggre
 
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
  * {@link org.apache.commons.functor.aggregator.AbstractListBackedAggregator}
  * which computes the arithmetic mean of all the numbers in the list.
  */
-public final class IntegerMeanValueAggregatorFunction implements UnaryFunction<List<Integer>, Integer> {
+public final class IntegerMeanValueAggregatorFunction implements Function<List<Integer>, Integer> {
     /**
      * Does the actual computation and returns the result. Please note that
      * caller is responsible for synchronizing access to the list.

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMedianValueAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMedianValueAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMedianValueAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerMedianValueAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
@@ -28,7 +28,7 @@ import org.apache.commons.functor.UnaryF
  * which computes the <a href="http://en.wikipedia.org/wiki/Median">median</a>
  * of all the numbers in the list.
  */
-public final class IntegerMedianValueAggregatorFunction implements UnaryFunction<List<Integer>, Integer> {
+public final class IntegerMedianValueAggregatorFunction implements Function<List<Integer>, Integer> {
     /**
      * Flag to indicate whether we are going to operate on a copy of the list
      * given or not. In order to compute the median, we need to sort the list

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerPercentileAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerPercentileAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerPercentileAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerPercentileAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
@@ -31,7 +31,7 @@ import org.apache.commons.functor.UnaryF
  * using formula: <code>n = round((P / 100) * N + 0.5)</code> where N is the
  * number of items in a list.
  */
-public class IntegerPercentileAggregatorFunction implements UnaryFunction<List<Integer>, Integer> {
+public class IntegerPercentileAggregatorFunction implements Function<List<Integer>, Integer> {
     /** A percentile goes from 0 to 100% and that's it. */
     private static final double MAX_PERCENTAGE = 100.0;
     /**

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerSumAggregatorFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerSumAggregatorFunction.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerSumAggregatorFunction.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/IntegerSumAggregatorFunction.java Tue Jul 30 22:48:02 2013
@@ -18,14 +18,14 @@ package org.apache.commons.functor.aggre
 
 import java.util.List;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Aggregator function to be used with subclasses of
  * {@link org.apache.commons.functor.aggregator.AbstractListBackedAggregator}
  * which sums up all the numbers in the list.
  */
-public final class IntegerSumAggregatorFunction implements UnaryFunction<List<Integer>, Integer> {
+public final class IntegerSumAggregatorFunction implements Function<List<Integer>, Integer> {
     /**
      * Does the actual adding and returns the result. Please note that caller is
      * responsible for synchronizing access to the list.

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/package-info.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/package-info.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/aggregator/functions/package-info.java Tue Jul 30 22:48:02 2013
@@ -17,7 +17,7 @@
 
 /**
  * <p>
- * This package contains <code>UnaryFunction</code>'s used by aggregators
+ * This package contains <code>Function</code>'s used by aggregators
  * defined in <code>org.apache.commons.functor.aggregator</code>.
  * </p>
  * <p>

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Constant.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Constant.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Constant.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Constant.java Tue Jul 30 22:48:02 2013
@@ -21,9 +21,9 @@ import java.io.Serializable;
 import org.apache.commons.functor.BinaryFunction;
 import org.apache.commons.functor.BinaryPredicate;
 import org.apache.commons.functor.Function;
+import org.apache.commons.functor.NullaryFunction;
+import org.apache.commons.functor.NullaryPredicate;
 import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.UnaryFunction;
-import org.apache.commons.functor.UnaryPredicate;
 
 /**
  * {@link #evaluate Evaluates} to constant value.
@@ -41,8 +41,8 @@ import org.apache.commons.functor.UnaryP
  * @param <T> the returned value type.
  * @version $Revision$ $Date$
  */
-public final class Constant<T> implements Function<T>, UnaryFunction<Object, T>, BinaryFunction<Object, Object, T>,
-        Predicate, UnaryPredicate<Object>, BinaryPredicate<Object, Object>, Serializable {
+public final class Constant<T> implements NullaryFunction<T>, Function<Object, T>, BinaryFunction<Object, Object, T>,
+        NullaryPredicate, Predicate<Object>, BinaryPredicate<Object, Object>, Serializable {
 
     // static attributes
     // ------------------------------------------------------------------------

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Identity.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Identity.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Identity.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Identity.java Tue Jul 30 22:48:02 2013
@@ -18,8 +18,8 @@ package org.apache.commons.functor.core;
 
 import java.io.Serializable;
 
-import org.apache.commons.functor.UnaryFunction;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Function;
+import org.apache.commons.functor.Predicate;
 
 /**
  * {@link #evaluate Evaluates} to its input argument.
@@ -33,7 +33,7 @@ import org.apache.commons.functor.UnaryP
  * @param <T> the returned value type.
  * @version $Revision$ $Date$
  */
-public final class Identity<T> implements UnaryFunction<T, T>, UnaryPredicate<T>, Serializable {
+public final class Identity<T> implements Function<T, T>, Predicate<T>, Serializable {
     // static attributes
     // ------------------------------------------------------------------------
     /**

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsEqual.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsEqual.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsEqual.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsEqual.java Tue Jul 30 22:48:02 2013
@@ -19,7 +19,7 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 
 /**
@@ -104,13 +104,13 @@ public final class IsEqual<L, R> impleme
     }
 
     /**
-     * Get an IsEqual UnaryPredicate.
+     * Get an IsEqual Predicate.
      * @param <L> the left argument type.
      * @param <R> the right argument type.
      * @param object bound comparison object
-     * @return UnaryPredicate<L>
+     * @return Predicate<L>
      */
-    public static <L, R> UnaryPredicate<L> to(R object) {
+    public static <L, R> Predicate<L> to(R object) {
         return new RightBoundPredicate<L>(new IsEqual<L, R>(), object);
     }
 }

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsInstance.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsInstance.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsInstance.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsInstance.java Tue Jul 30 22:48:02 2013
@@ -19,7 +19,7 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 
 /**
@@ -93,12 +93,12 @@ public final class IsInstance<T> impleme
     }
 
     /**
-     * Get an IsInstanceOf UnaryPredicate.
+     * Get an IsInstanceOf Predicate.
      * @param <T> the object instance has to be tested against the input class.
      * @param clazz bound right-side argument
-     * @return UnaryPredicate<T>
+     * @return Predicate<T>
      */
-    public static <T> UnaryPredicate<T> of(Class<?> clazz) {
+    public static <T> Predicate<T> of(Class<?> clazz) {
         return RightBoundPredicate.bind(new IsInstance<T>(), clazz);
     }
 }

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotEqual.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotEqual.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotEqual.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotEqual.java Tue Jul 30 22:48:02 2013
@@ -19,7 +19,7 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 
 /**
@@ -102,13 +102,13 @@ public final class IsNotEqual<L, R> impl
     }
 
     /**
-     * Get an IsNotEqual UnaryPredicate.
+     * Get an IsNotEqual Predicate.
      * @param <L> the left argument type.
      * @param <R> the right argument type.
      * @param object bound comparison object
-     * @return UnaryPredicate<L>
+     * @return Predicate<L>
      */
-    public static <L, R> UnaryPredicate<L> to(R object) {
+    public static <L, R> Predicate<L> to(R object) {
         return new RightBoundPredicate<L>(new IsNotEqual<L, R>(), object);
     }
 }

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotNull.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotNull.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotNull.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotNull.java Tue Jul 30 22:48:02 2013
@@ -19,7 +19,7 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.IgnoreLeftPredicate;
 import org.apache.commons.functor.adapter.IgnoreRightPredicate;
 
@@ -31,7 +31,7 @@ import org.apache.commons.functor.adapte
  * @param <T> the argument type.
  * @version $Revision$ $Date$
  */
-public final class IsNotNull<T> implements UnaryPredicate<T>, Serializable {
+public final class IsNotNull<T> implements Predicate<T>, Serializable {
 
     // static attributes
     // ------------------------------------------------------------------------

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotSame.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotSame.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotSame.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNotSame.java Tue Jul 30 22:48:02 2013
@@ -19,7 +19,7 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 
 /**
@@ -95,13 +95,13 @@ public final class IsNotSame<L, R> imple
     }
 
     /**
-     * Get an IsNotSame UnaryPredicate.
+     * Get an IsNotSame Predicate.
      * @param <L> the left argument type.
      * @param <R> the right argument type.
      * @param object bound comparison object
-     * @return UnaryPredicate<L>
+     * @return Predicate<L>
      */
-    public static <L, R> UnaryPredicate<L> as(R object) {
+    public static <L, R> Predicate<L> as(R object) {
         return new RightBoundPredicate<L>(new IsNotSame<L, R>(), object);
     }
 }

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNull.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNull.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNull.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsNull.java Tue Jul 30 22:48:02 2013
@@ -19,7 +19,7 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.IgnoreLeftPredicate;
 import org.apache.commons.functor.adapter.IgnoreRightPredicate;
 
@@ -31,7 +31,7 @@ import org.apache.commons.functor.adapte
  * @param <A> the argument type.
  * @version $Revision$ $Date$
  */
-public final class IsNull<A> implements UnaryPredicate<A>, Serializable {
+public final class IsNull<A> implements Predicate<A>, Serializable {
 
     // static attributes
     // ------------------------------------------------------------------------

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsSame.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsSame.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsSame.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/IsSame.java Tue Jul 30 22:48:02 2013
@@ -19,7 +19,7 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 
 /**
@@ -95,13 +95,13 @@ public final class IsSame<L, R> implemen
     }
 
     /**
-     * Get an IsSame UnaryPredicate.
+     * Get an IsSame Predicate.
      * @param <L> the left argument type.
      * @param <R> the right argument type.
      * @param object bound comparison object
-     * @return UnaryPredicate<L>
+     * @return Predicate<L>
      */
-    public static <L, R> UnaryPredicate<L> as(R object) {
+    public static <L, R> Predicate<L> as(R object) {
         return new RightBoundPredicate<L>(new IsSame<L, R>(), object);
     }
 }

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Limit.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Limit.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Limit.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Limit.java Tue Jul 30 22:48:02 2013
@@ -20,8 +20,8 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
+import org.apache.commons.functor.NullaryPredicate;
 import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.UnaryPredicate;
 
 /**
  * A predicate that returns <code>true</code>
@@ -31,7 +31,7 @@ import org.apache.commons.functor.UnaryP
  * @since 1.0
  * @version $Revision$ $Date$
  */
-public final class Limit implements Predicate, UnaryPredicate<Object>, BinaryPredicate<Object, Object>, Serializable {
+public final class Limit implements NullaryPredicate, Predicate<Object>, BinaryPredicate<Object, Object>, Serializable {
     // static attributes
     // ------------------------------------------------------------------------
     /**

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/NoOp.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/NoOp.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/NoOp.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/NoOp.java Tue Jul 30 22:48:02 2013
@@ -19,18 +19,18 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryProcedure;
+import org.apache.commons.functor.NullaryProcedure;
 import org.apache.commons.functor.Procedure;
-import org.apache.commons.functor.UnaryProcedure;
 
 /**
  * A procedure that does nothing at all.
  * <p>
  * Note that this class implements {@link Procedure},
- * {@link UnaryProcedure}, and {@link BinaryProcedure}.
+ * {@link Procedure}, and {@link BinaryProcedure}.
  * </p>
  * @version $Revision$ $Date$
  */
-public final class NoOp implements Procedure, UnaryProcedure<Object>, BinaryProcedure<Object, Object>, Serializable {
+public final class NoOp implements NullaryProcedure, Procedure<Object>, BinaryProcedure<Object, Object>, Serializable {
     // static attributes
     // ------------------------------------------------------------------------
     /**
@@ -105,13 +105,13 @@ public final class NoOp implements Proce
     }
 
     /**
-     * Get a typed NoOp {@link UnaryProcedure}.
+     * Get a typed NoOp {@link Procedure}.
      * @param <A> type
-     * @return <code>UnaryProcedure&lt;A&gt;</code>
+     * @return <code>Procedure&lt;A&gt;</code>
      */
     @SuppressWarnings("unchecked")
-    public static <A> UnaryProcedure<A> unaryInstance() {
-        return (UnaryProcedure<A>) INSTANCE;
+    public static <A> Procedure<A> unaryInstance() {
+        return (Procedure<A>) INSTANCE;
     }
 
     /**

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Offset.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Offset.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Offset.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/Offset.java Tue Jul 30 22:48:02 2013
@@ -19,8 +19,8 @@ package org.apache.commons.functor.core;
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
+import org.apache.commons.functor.NullaryPredicate;
 import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.UnaryPredicate;
 
 /**
  * A predicate that returns <code>false</code>
@@ -30,7 +30,8 @@ import org.apache.commons.functor.UnaryP
  * @since 1.0
  * @version $Revision$ $Date$
  */
-public final class Offset implements Predicate, UnaryPredicate<Object>, BinaryPredicate<Object, Object>, Serializable {
+public final class Offset implements NullaryPredicate, Predicate<Object>,
+        BinaryPredicate<Object, Object>, Serializable {
     // static attributes
     // ------------------------------------------------------------------------
     /**

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoUntil.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoUntil.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoUntil.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoUntil.java Tue Jul 30 22:48:02 2013
@@ -16,8 +16,8 @@
  */
 package org.apache.commons.functor.core.algorithm;
 
-import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.Procedure;
+import org.apache.commons.functor.NullaryPredicate;
+import org.apache.commons.functor.NullaryProcedure;
 
 /**
  * Do-until algorithm (test after).
@@ -36,7 +36,7 @@ public class DoUntil extends PredicatedL
      * @param body to execute
      * @param test whether to keep going
      */
-    public DoUntil(Procedure body, Predicate test) {
+    public DoUntil(NullaryProcedure body, NullaryPredicate test) {
         super(body, test);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoWhile.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoWhile.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoWhile.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/DoWhile.java Tue Jul 30 22:48:02 2013
@@ -16,8 +16,8 @@
  */
 package org.apache.commons.functor.core.algorithm;
 
-import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.Procedure;
+import org.apache.commons.functor.NullaryPredicate;
+import org.apache.commons.functor.NullaryProcedure;
 
 /**
  * Do-while algorithm (test after).
@@ -36,7 +36,7 @@ public class DoWhile extends PredicatedL
      * @param body to execute
      * @param test whether to keep going
      */
-    public DoWhile(Procedure body, Predicate test) {
+    public DoWhile(NullaryProcedure body, NullaryPredicate test) {
         super(body, test);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FindWithinGenerator.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FindWithinGenerator.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FindWithinGenerator.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FindWithinGenerator.java Tue Jul 30 22:48:02 2013
@@ -20,18 +20,18 @@ import java.io.Serializable;
 import java.util.NoSuchElementException;
 
 import org.apache.commons.functor.BinaryFunction;
-import org.apache.commons.functor.UnaryPredicate;
-import org.apache.commons.functor.UnaryProcedure;
+import org.apache.commons.functor.Predicate;
+import org.apache.commons.functor.Procedure;
 import org.apache.commons.functor.generator.Generator;
 
 /**
- * Return the first Object in a {@link Generator} matching a {@link UnaryPredicate}.
+ * Return the first Object in a {@link Generator} matching a {@link Predicate}.
  *
  * @param <E> the arguments type.
  * @version $Revision$ $Date$
  */
 public final class FindWithinGenerator<E>
-    implements BinaryFunction<Generator<? extends E>, UnaryPredicate<? super E>, E>, Serializable {
+    implements BinaryFunction<Generator<? extends E>, Predicate<? super E>, E>, Serializable {
 
     /**
      * Basic instance.
@@ -48,7 +48,7 @@ public final class FindWithinGenerator<E
      *
      * @param <T> the argument type.
      */
-    private static class FindProcedure<T> implements UnaryProcedure<T> {
+    private static class FindProcedure<T> implements Procedure<T> {
         /**
          * The object found, if any.
          */
@@ -60,13 +60,13 @@ public final class FindWithinGenerator<E
         /**
          * The adapted predicate.
          */
-        private UnaryPredicate<? super T> pred;
+        private Predicate<? super T> pred;
 
         /**
          * Create a new FindProcedure.
          * @param pred the adapted predicate.
          */
-        public FindProcedure(UnaryPredicate<? super T> pred) {
+        public FindProcedure(Predicate<? super T> pred) {
             this.pred = pred;
         }
 
@@ -82,7 +82,7 @@ public final class FindWithinGenerator<E
     }
 
     /**
-     * Flag to mark the {@link FindWithinGenerator#evaluate(Generator, UnaryPredicate)} method must return a user
+     * Flag to mark the {@link FindWithinGenerator#evaluate(Generator, Predicate)} method must return a user
      * defined object when the adapted procedure does not find any object.
      */
     private final boolean useIfNone;
@@ -113,9 +113,9 @@ public final class FindWithinGenerator<E
     /**
      * {@inheritDoc}
      * @param left Generator
-     * @param right UnaryPredicate
+     * @param right Predicate
      */
-    public E evaluate(Generator<? extends E> left, UnaryPredicate<? super E> right) {
+    public E evaluate(Generator<? extends E> left, Predicate<? super E> right) {
         FindProcedure<E> findProcedure = new FindProcedure<E>(right);
         left.run(findProcedure);
         if (!findProcedure.wasFound) {

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldLeft.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldLeft.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldLeft.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldLeft.java Tue Jul 30 22:48:02 2013
@@ -19,8 +19,8 @@ package org.apache.commons.functor.core.
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryFunction;
-import org.apache.commons.functor.UnaryFunction;
-import org.apache.commons.functor.UnaryProcedure;
+import org.apache.commons.functor.Function;
+import org.apache.commons.functor.Procedure;
 import org.apache.commons.functor.generator.Generator;
 
 /**
@@ -32,7 +32,7 @@ import org.apache.commons.functor.genera
  * @param <T> the returned evaluation type.
  * @version $Revision$ $Date$
  */
-public class FoldLeft<T> implements UnaryFunction<Generator<T>, T>, BinaryFunction<Generator<T>, T, T>, Serializable {
+public class FoldLeft<T> implements Function<Generator<T>, T>, BinaryFunction<Generator<T>, T, T>, Serializable {
 
     /**
      * serialVersionUID declaration.
@@ -44,7 +44,7 @@ public class FoldLeft<T> implements Unar
      *
      * @param <T> the returned evaluation type.
      */
-    private static class FoldLeftHelper<T> implements UnaryProcedure<T> {
+    private static class FoldLeftHelper<T> implements Procedure<T> {
         /**
          * The wrapped function.
          */

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldRight.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldRight.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldRight.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/FoldRight.java Tue Jul 30 22:48:02 2013
@@ -20,8 +20,8 @@ import java.io.Serializable;
 import java.util.Stack;
 
 import org.apache.commons.functor.BinaryFunction;
-import org.apache.commons.functor.UnaryFunction;
-import org.apache.commons.functor.UnaryProcedure;
+import org.apache.commons.functor.Function;
+import org.apache.commons.functor.Procedure;
 import org.apache.commons.functor.generator.Generator;
 
 /**
@@ -33,7 +33,7 @@ import org.apache.commons.functor.genera
  * @param <T> the returned evaluation type.
  * @version $Revision$ $Date$
  */
-public class FoldRight<T> implements UnaryFunction<Generator<T>, T>, BinaryFunction<Generator<T>, T, T>, Serializable {
+public class FoldRight<T> implements Function<Generator<T>, T>, BinaryFunction<Generator<T>, T, T>, Serializable {
 
     /**
      * serialVersionUID declaration.
@@ -45,7 +45,7 @@ public class FoldRight<T> implements Una
      *
      * @param <T> the returned evaluation type.
      */
-    private static class FoldRightHelper<T> implements UnaryProcedure<T> {
+    private static class FoldRightHelper<T> implements Procedure<T> {
         /**
          * The stack where storing the wrapped function evaluations.
          */

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/GeneratorContains.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/GeneratorContains.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/GeneratorContains.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/GeneratorContains.java Tue Jul 30 22:48:02 2013
@@ -19,17 +19,17 @@ package org.apache.commons.functor.core.
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
-import org.apache.commons.functor.UnaryProcedure;
+import org.apache.commons.functor.Predicate;
+import org.apache.commons.functor.Procedure;
 import org.apache.commons.functor.generator.Generator;
 
 /**
- * Tests whether a {@link Generator} contains an element that matches a {@link UnaryPredicate}.
+ * Tests whether a {@link Generator} contains an element that matches a {@link Predicate}.
  *
  * @param <T> the predicate argument type.
  * @version $Revision$ $Date$
  */
-public final class GeneratorContains<T> implements BinaryPredicate<Generator<? extends T>, UnaryPredicate<? super T>>,
+public final class GeneratorContains<T> implements BinaryPredicate<Generator<? extends T>, Predicate<? super T>>,
         Serializable {
     /**
      * serialVersionUID declaration.
@@ -45,11 +45,11 @@ public final class GeneratorContains<T> 
      *
      * @param <T> the predicate argument type.
      */
-    private static class ContainsProcedure<T> implements UnaryProcedure<T> {
+    private static class ContainsProcedure<T> implements Procedure<T> {
         /**
          * The wrapped predicate.
          */
-        private final UnaryPredicate<? super T> pred;
+        private final Predicate<? super T> pred;
         /**
          * Flag to mark if the wrapped predicate succeeded or not.
          */
@@ -60,7 +60,7 @@ public final class GeneratorContains<T> 
          *
          * @param pred The wrapped predicate
          */
-        public ContainsProcedure(UnaryPredicate<? super T> pred) {
+        public ContainsProcedure(Predicate<? super T> pred) {
             this.pred = pred;
         }
 
@@ -75,9 +75,9 @@ public final class GeneratorContains<T> 
     /**
      * {@inheritDoc}
      * @param left Generator
-     * @param right UnaryPredicate
+     * @param right Predicate
      */
-    public boolean test(Generator<? extends T> left, UnaryPredicate<? super T> right) {
+    public boolean test(Generator<? extends T> left, Predicate<? super T> right) {
         ContainsProcedure<T> findProcedure = new ContainsProcedure<T>(right);
         left.run(findProcedure);
         return findProcedure.found;

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/InPlaceTransform.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/InPlaceTransform.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/InPlaceTransform.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/InPlaceTransform.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.ListIterator;
 
 import org.apache.commons.functor.BinaryProcedure;
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 
 /**
  * Implements an in-place transformation of a ListIterator's contents.
@@ -29,7 +29,7 @@ import org.apache.commons.functor.UnaryF
  * @version $Revision$ $Date$
  */
 public final class InPlaceTransform<T>
-    implements BinaryProcedure<ListIterator<T>, UnaryFunction<? super T, ? extends T>>, Serializable {
+    implements BinaryProcedure<ListIterator<T>, Function<? super T, ? extends T>>, Serializable {
     /**
      * serialVersionUID declaration.
      */
@@ -42,9 +42,9 @@ public final class InPlaceTransform<T>
     /**
      * {@inheritDoc}
      * @param left {@link ListIterator}
-     * @param right {@link UnaryFunction}
+     * @param right {@link Function}
      */
-    public void run(ListIterator<T> left, UnaryFunction<? super T, ? extends T> right) {
+    public void run(ListIterator<T> left, Function<? super T, ? extends T> right) {
         while (left.hasNext()) {
             left.set(right.evaluate(left.next()));
         }

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/IndexOfInGenerator.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/IndexOfInGenerator.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/IndexOfInGenerator.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/IndexOfInGenerator.java Tue Jul 30 22:48:02 2013
@@ -19,18 +19,18 @@ package org.apache.commons.functor.core.
 import java.io.Serializable;
 
 import org.apache.commons.functor.BinaryFunction;
-import org.apache.commons.functor.UnaryPredicate;
-import org.apache.commons.functor.UnaryProcedure;
+import org.apache.commons.functor.Predicate;
+import org.apache.commons.functor.Procedure;
 import org.apache.commons.functor.generator.Generator;
 
 /**
- * Return the index of the first Object in a {@link Generator} matching a {@link UnaryPredicate}, or -1 if not found.
+ * Return the index of the first Object in a {@link Generator} matching a {@link Predicate}, or -1 if not found.
  *
  * @param <T> the procedure argument types
  * @version $Revision$ $Date$
  */
 public final class IndexOfInGenerator<T>
-    implements BinaryFunction<Generator<? extends T>, UnaryPredicate<? super T>, Number>, Serializable {
+    implements BinaryFunction<Generator<? extends T>, Predicate<? super T>, Number>, Serializable {
     /**
      * serialVersionUID declaration.
      */
@@ -45,7 +45,7 @@ public final class IndexOfInGenerator<T>
      *
      * @param <T> the procedure argument type
      */
-    private static class IndexProcedure<T> implements UnaryProcedure<T> {
+    private static class IndexProcedure<T> implements Procedure<T> {
         /**
          * The wrapped generator.
          */
@@ -53,7 +53,7 @@ public final class IndexOfInGenerator<T>
         /**
          * The wrapped predicate.
          */
-        private final UnaryPredicate<? super T> pred;
+        private final Predicate<? super T> pred;
         /**
          * The number of iterations needed before the wrapped predicate found the target,
          * {@code -1} means the target was not found.
@@ -70,7 +70,7 @@ public final class IndexOfInGenerator<T>
          * @param generator The wrapped generator
          * @param pred The wrapped predicate
          */
-        IndexProcedure(Generator<? extends T> generator, UnaryPredicate<? super T> pred) {
+        IndexProcedure(Generator<? extends T> generator, Predicate<? super T> pred) {
             this.generator = generator;
             this.pred = pred;
         }
@@ -90,9 +90,9 @@ public final class IndexOfInGenerator<T>
     /**
      * {@inheritDoc}
      * @param left Generator
-     * @param right UnaryPredicate
+     * @param right Predicate
      */
-    public Number evaluate(Generator<? extends T> left, UnaryPredicate<? super T> right) {
+    public Number evaluate(Generator<? extends T> left, Predicate<? super T> right) {
         IndexProcedure<T> findProcedure = new IndexProcedure<T>(left, right);
         left.run(findProcedure);
         return Long.valueOf(findProcedure.index);

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/PredicatedLoop.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/PredicatedLoop.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/PredicatedLoop.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/PredicatedLoop.java Tue Jul 30 22:48:02 2013
@@ -18,15 +18,15 @@ package org.apache.commons.functor.core.
 
 import java.io.Serializable;
 
-import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.Procedure;
+import org.apache.commons.functor.NullaryPredicate;
+import org.apache.commons.functor.NullaryProcedure;
 
 /**
  * Base class for predicated procedure algorithms.
  *
  * @version $Revision$ $Date$
  */
-abstract class PredicatedLoop implements Procedure, Serializable {
+abstract class PredicatedLoop implements NullaryProcedure, Serializable {
     /**
      * serialVersionUID declaration.
      */
@@ -34,35 +34,35 @@ abstract class PredicatedLoop implements
     /**
      * The procedure body to execute.
      */
-    private final Procedure body;
+    private final NullaryProcedure body;
     /**
      * The test wether to keep going.
      */
-    private final Predicate test;
+    private final NullaryPredicate test;
 
     /**
      * Create a new PredicatedLoop.
      * @param body to execute
      * @param test whether to keep going
      */
-    protected PredicatedLoop(Procedure body, Predicate test) {
+    protected PredicatedLoop(NullaryProcedure body, NullaryPredicate test) {
         this.body = body;
         this.test = test;
     }
 
     /**
      * Get the body of this loop.
-     * @return Procedure
+     * @return NullaryProcedure
      */
-    protected Procedure getBody() {
+    protected NullaryProcedure getBody() {
         return body;
     }
 
     /**
      * Get the test for this loop.
-     * @return Predicate
+     * @return NullaryPredicate
      */
-    protected Predicate getTest() {
+    protected NullaryPredicate getTest() {
         return test;
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RecursiveEvaluation.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RecursiveEvaluation.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RemoveMatching.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RemoveMatching.java Tue Jul 30 22:48:02 2013
@@ -20,16 +20,16 @@ import java.io.Serializable;
 import java.util.Iterator;
 
 import org.apache.commons.functor.BinaryProcedure;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 
 /**
- * Remove elements from left Iterator that match right UnaryPredicate.
+ * Remove elements from left Iterator that match right Predicate.
  *
  * @param <T> the procedure argument type.
  * @version $Revision$ $Date$
  */
 public final class RemoveMatching<T>
-    implements BinaryProcedure<Iterator<? extends T>, UnaryPredicate<? super T>>, Serializable {
+    implements BinaryProcedure<Iterator<? extends T>, Predicate<? super T>>, Serializable {
     /**
      * serialVersionUID declaration.
      */
@@ -42,9 +42,9 @@ public final class RemoveMatching<T>
     /**
      * {@inheritDoc}
      * @param left {@link Iterator}
-     * @param right {@link UnaryPredicate}
+     * @param right {@link Predicate}
      */
-    public void run(Iterator<? extends T> left, UnaryPredicate<? super T> right) {
+    public void run(Iterator<? extends T> left, Predicate<? super T> right) {
         while (left.hasNext()) {
             if (right.test(left.next())) {
                 left.remove();

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RetainMatching.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RetainMatching.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RetainMatching.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RetainMatching.java Tue Jul 30 22:48:02 2013
@@ -20,17 +20,17 @@ import java.io.Serializable;
 import java.util.Iterator;
 
 import org.apache.commons.functor.BinaryProcedure;
-import org.apache.commons.functor.UnaryPredicate;
-import org.apache.commons.functor.core.composite.UnaryNot;
+import org.apache.commons.functor.Predicate;
+import org.apache.commons.functor.core.composite.Not;
 
 /**
- * Retain elements in left Iterator that match right UnaryPredicate.
+ * Retain elements in left Iterator that match right Predicate.
  *
  * @param <T> the procedure argument type
  * @version $Revision$ $Date$
  */
 public final class RetainMatching<T>
-    implements BinaryProcedure<Iterator<? extends T>, UnaryPredicate<? super T>>, Serializable {
+    implements BinaryProcedure<Iterator<? extends T>, Predicate<? super T>>, Serializable {
     /**
      * serialVersionUID declaration.
      */
@@ -47,10 +47,10 @@ public final class RetainMatching<T>
     /**
      * {@inheritDoc}
      * @param left {@link Iterator}
-     * @param right {@link UnaryPredicate}
+     * @param right {@link Predicate}
      */
-    public void run(Iterator<? extends T> left, UnaryPredicate<? super T> right) {
-        removeMatching.run(left, UnaryNot.not(right));
+    public void run(Iterator<? extends T> left, Predicate<? super T> right) {
+        removeMatching.run(left, Not.not(right));
     }
 
     /**

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/UntilDo.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/UntilDo.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/UntilDo.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/UntilDo.java Tue Jul 30 22:48:02 2013
@@ -16,8 +16,8 @@
  */
 package org.apache.commons.functor.core.algorithm;
 
-import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.Procedure;
+import org.apache.commons.functor.NullaryPredicate;
+import org.apache.commons.functor.NullaryProcedure;
 
 /**
  * Until-do algorithm (test before).
@@ -36,7 +36,7 @@ public class UntilDo extends PredicatedL
      * @param test whether to keep going
      * @param body to execute
      */
-    public UntilDo(Predicate test, Procedure body) {
+    public UntilDo(NullaryPredicate test, NullaryProcedure body) {
         super(body, test);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/WhileDo.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/WhileDo.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/WhileDo.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/WhileDo.java Tue Jul 30 22:48:02 2013
@@ -16,8 +16,8 @@
  */
 package org.apache.commons.functor.core.algorithm;
 
-import org.apache.commons.functor.Predicate;
-import org.apache.commons.functor.Procedure;
+import org.apache.commons.functor.NullaryPredicate;
+import org.apache.commons.functor.NullaryProcedure;
 
 /**
  * While-do algorithm (test before).
@@ -36,7 +36,7 @@ public class WhileDo extends PredicatedL
      * @param test whether to keep going
      * @param body to execute
      */
-    public WhileDo(Predicate test, Procedure body) {
+    public WhileDo(NullaryPredicate test, NullaryProcedure body) {
         super(body, test);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterable.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterable.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterable.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterable.java Tue Jul 30 22:48:02 2013
@@ -19,10 +19,10 @@ package org.apache.commons.functor.core.
 import java.util.Collections;
 import java.util.Iterator;
 
-import org.apache.commons.functor.UnaryFunction;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Function;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.core.IsInstance;
-import org.apache.commons.functor.core.composite.UnaryAnd;
+import org.apache.commons.functor.core.composite.And;
 
 /**
  * Adds a fluent filtering API to any {@link Iterable}.
@@ -50,7 +50,7 @@ public class FilteredIterable<T> impleme
          * {@inheritDoc}
          */
         @Override
-        public FilteredIterable retain(UnaryPredicate predicate) {
+        public FilteredIterable retain(Predicate predicate) {
             return this;
         }
 
@@ -70,7 +70,7 @@ public class FilteredIterable<T> impleme
     /**
      * The predicate used to test input {@link Iterable} elements.
      */
-    private UnaryAnd<T> predicate;
+    private And<T> predicate;
 
     /**
      * Create a new FilteredIterable.
@@ -85,7 +85,7 @@ public class FilteredIterable<T> impleme
      * {@inheritDoc}
      */
     public Iterator<T> iterator() {
-        UnaryPredicate<T> predicateReference;
+        Predicate<T> predicateReference;
         synchronized (this) {
             predicateReference = predicate;
         }
@@ -105,13 +105,13 @@ public class FilteredIterable<T> impleme
      * @param filter filter predicate, non-<code>null</code>
      * @return <code>this</code>, fluently
      */
-    public FilteredIterable<T> retain(UnaryPredicate<? super T> filter) {
+    public FilteredIterable<T> retain(Predicate<? super T> filter) {
         if (filter == null) {
             throw new NullPointerException("filtering predicate was null");
         }
         synchronized (this) {
             if (this.predicate == null) {
-                this.predicate = new UnaryAnd<T>();
+                this.predicate = new And<T>();
             }
             this.predicate.and(filter);
         }
@@ -134,7 +134,7 @@ public class FilteredIterable<T> impleme
             public Iterator<U> iterator() {
                 return TransformedIterator.transform(
                         FilteredIterator.filter(FilteredIterable.this.iterator(), IsInstance.of(type)),
-                        new UnaryFunction<T, U>() {
+                        new Function<T, U>() {
 
                             @SuppressWarnings("unchecked")
                             // this is okay because of the isinstance check
@@ -156,7 +156,7 @@ public class FilteredIterable<T> impleme
         if (ofType == null) {
             throw new NullPointerException("array of filtered types was null");
         }
-        return retain(new UnaryPredicate<T>() {
+        return retain(new Predicate<T>() {
 
             public boolean test(T obj) {
                 for (Class<?> type : ofType) {

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterator.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterator.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/FilteredIterator.java Tue Jul 30 22:48:02 2013
@@ -19,12 +19,12 @@ package org.apache.commons.functor.core.
 import java.util.Iterator;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.lang3.Validate;
 
 /**
  * Iterator that filters another Iterator by only passing through those elements
- * that are matched by a specified UnaryPredicate.
+ * that are matched by a specified Predicate.
  *
  * @param <T> the {@link Iterator} generic type
  * @version $Revision$ $Date$
@@ -36,7 +36,7 @@ public final class FilteredIterator<T> i
     /**
      * The predicate used to test this Iterator elements.
      */
-    private final UnaryPredicate<? super T> predicate;
+    private final Predicate<? super T> predicate;
     /**
      * The wrapped iterator.
      */
@@ -62,9 +62,9 @@ public final class FilteredIterator<T> i
      * @param iterator to filter
      * @param predicate to apply
      */
-    public FilteredIterator(Iterator<? extends T> iterator, UnaryPredicate<? super T> predicate) {
+    public FilteredIterator(Iterator<? extends T> iterator, Predicate<? super T> predicate) {
         this.iterator = Validate.notNull(iterator, "Iterator argument was null");
-        this.predicate = Validate.notNull(predicate, "filtering UnaryPredicate argument was null");
+        this.predicate = Validate.notNull(predicate, "filtering Predicate argument was null");
     }
 
     // iterator methods
@@ -148,7 +148,7 @@ public final class FilteredIterator<T> i
      * @return Iterator
      */
     @SuppressWarnings("unchecked")
-    public static <T> Iterator<T> filter(Iterator<? extends T> iter, UnaryPredicate<? super T> pred) {
+    public static <T> Iterator<T> filter(Iterator<? extends T> iter, Predicate<? super T> pred) {
         return null == pred ? (Iterator<T>) iter : (null == iter ? null : new FilteredIterator<T>(iter, pred));
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsElementOf.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsElementOf.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsElementOf.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsElementOf.java Tue Jul 30 22:48:02 2013
@@ -21,7 +21,7 @@ import java.lang.reflect.Array;
 import java.util.Collection;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 import org.apache.commons.lang3.Validate;
 
@@ -136,13 +136,13 @@ public final class IsElementOf<L, R> imp
     }
 
     /**
-     * Get an IsElementOf(collection|array) UnaryPredicate.
+     * Get an IsElementOf(collection|array) Predicate.
      *
-     * @param <A> the UnaryPredicate argument generic type
+     * @param <A> the Predicate argument generic type
      * @param obj collection/array to search
-     * @return UnaryPredicate
+     * @return Predicate
      */
-    public static <A> UnaryPredicate<A> instance(Object obj) {
+    public static <A> Predicate<A> instance(Object obj) {
         if (null == obj) {
             throw new NullPointerException("Argument must not be null");
         } else if (obj instanceof Collection<?>) {

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsEmpty.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsEmpty.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsEmpty.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/IsEmpty.java Tue Jul 30 22:48:02 2013
@@ -21,14 +21,14 @@ import java.lang.reflect.Array;
 import java.util.Collection;
 import java.util.Map;
 
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.lang3.Validate;
 
 /**
  * @param <A> the predicate argument type.
  * @version $Revision$ $Date$
  */
-public final class IsEmpty<A> implements UnaryPredicate<A>, Serializable {
+public final class IsEmpty<A> implements Predicate<A>, Serializable {
 
     // class variables
     // ------------------------------------------------------------------------

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/Size.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/Size.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/Size.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/Size.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.lang.reflect.Array;
 import java.util.Collection;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 import org.apache.commons.lang3.Validate;
 
 /**
@@ -30,7 +30,7 @@ import org.apache.commons.lang3.Validate
  * @param <A> the function argument type.
  * @version $Revision$ $Date$
  */
-public final class Size<A> implements UnaryFunction<A, Integer>, Serializable {
+public final class Size<A> implements Function<A, Integer>, Serializable {
 
     /**
      * serialVersionUID declaration.

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/TransformedIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/TransformedIterator.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/TransformedIterator.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/collection/TransformedIterator.java Tue Jul 30 22:48:02 2013
@@ -18,11 +18,11 @@ package org.apache.commons.functor.core.
 
 import java.util.Iterator;
 
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 import org.apache.commons.lang3.Validate;
 
 /**
- * Iterator that transforms another Iterator by applying a UnaryFunction to each returned element.
+ * Iterator that transforms another Iterator by applying a Function to each returned element.
  *
  * @param <E> the function argument type
  * @param <T> the iterator elements type
@@ -36,7 +36,7 @@ public final class TransformedIterator<E
     /**
      * The function to apply to each iterator element.
      */
-    private final UnaryFunction<? super E, ? extends T> function;
+    private final Function<? super E, ? extends T> function;
     /**
      * The wrapped iterator.
      */
@@ -49,8 +49,8 @@ public final class TransformedIterator<E
      * @param iterator Iterator to decorate
      * @param function to apply
      */
-    public TransformedIterator(Iterator<? extends E> iterator, UnaryFunction<? super E, ? extends T> function) {
-        this.function = Validate.notNull(function, "filtering UnaryFunction argument was null");
+    public TransformedIterator(Iterator<? extends E> iterator, Function<? super E, ? extends T> function) {
+        this.function = Validate.notNull(function, "filtering Function argument was null");
         this.iterator = Validate.notNull(iterator, "Iterator argument was null");
     }
 
@@ -128,7 +128,7 @@ public final class TransformedIterator<E
      * @param func transforming function, cannot be null
      * @return Iterator<T>
      */
-    public static <E, T> Iterator<T> transform(Iterator<? extends E> iter, UnaryFunction<? super E, ? extends T> func) {
+    public static <E, T> Iterator<T> transform(Iterator<? extends E> iter, Function<? super E, ? extends T> func) {
         if (null == iter) {
             return null;
         }
@@ -143,7 +143,7 @@ public final class TransformedIterator<E
      * @param func transforming function, if null result is iter
      * @return Iterator<?>
      */
-    public static <E> Iterator<?> maybeTransform(Iterator<? extends E> iter, UnaryFunction<? super E, ?> func) {
+    public static <E> Iterator<?> maybeTransform(Iterator<? extends E> iter, Function<? super E, ?> func) {
         return null == func ? (null == iter ? null : iter) : new TransformedIterator<E, Object>(iter, func);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsEquivalent.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsEquivalent.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsEquivalent.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsEquivalent.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.Comparator;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 import org.apache.commons.lang3.Validate;
 
@@ -137,9 +137,9 @@ public final class IsEquivalent<T> imple
      *
      * @param <T> the predicate input type
      * @param right argument
-     * @return UnaryPredicate
+     * @return Predicate
      */
-    public static <T extends Comparable<?>> UnaryPredicate<T> instance(T right) {
+    public static <T extends Comparable<?>> Predicate<T> instance(T right) {
         return RightBoundPredicate.bind(instance(), right);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThan.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThan.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThan.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThan.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.Comparator;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 import org.apache.commons.lang3.Validate;
 
@@ -132,13 +132,13 @@ public final class IsGreaterThan<T> impl
     }
 
     /**
-     * Get an IsGreaterThan UnaryPredicate.
+     * Get an IsGreaterThan Predicate.
      *
      * @param <T> the binary predicate input types
      * @param right the right side object of the IsGreaterThan comparison
-     * @return UnaryPredicate<T>
+     * @return Predicate<T>
      */
-    public static <T extends Comparable<?>> UnaryPredicate<T> instance(T right) {
+    public static <T extends Comparable<?>> Predicate<T> instance(T right) {
         return RightBoundPredicate.bind(new IsGreaterThan<T>(), right);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThanOrEqual.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThanOrEqual.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThanOrEqual.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsGreaterThanOrEqual.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.Comparator;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 import org.apache.commons.lang3.Validate;
 
@@ -133,13 +133,13 @@ public final class IsGreaterThanOrEqual<
     }
 
     /**
-     * Get an IsGreaterThanOrEqual UnaryPredicate.
+     * Get an IsGreaterThanOrEqual Predicate.
      *
      * @param <T> the binary predicate input types
      * @param right the right side object of the IsGreaterThanOrEqual comparison
-     * @return UnaryPredicate
+     * @return Predicate
      */
-    public static <T extends Comparable<?>> UnaryPredicate<T> instance(T right) {
+    public static <T extends Comparable<?>> Predicate<T> instance(T right) {
         return RightBoundPredicate.bind(new IsGreaterThanOrEqual<T>(), right);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThan.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThan.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThan.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThan.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.Comparator;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 import org.apache.commons.lang3.Validate;
 
@@ -132,13 +132,13 @@ public final class IsLessThan<T> impleme
     }
 
     /**
-     * Get an IsLessThan UnaryPredicate.
+     * Get an IsLessThan Predicate.
      *
      * @param <T> the binary predicate input types
      * @param right the right side object of the comparison.
-     * @return UnaryPredicate
+     * @return Predicate
      */
-    public static <T extends Comparable<?>> UnaryPredicate<T> instance(T right) {
+    public static <T extends Comparable<?>> Predicate<T> instance(T right) {
         return RightBoundPredicate.bind(new IsLessThan<T>(), right);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThanOrEqual.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThanOrEqual.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThanOrEqual.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsLessThanOrEqual.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.Comparator;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 import org.apache.commons.lang3.Validate;
 
@@ -132,13 +132,13 @@ public final class IsLessThanOrEqual<T> 
     }
 
     /**
-     * Get an IsLessThanOrEqual UnaryPredicate.
+     * Get an IsLessThanOrEqual Predicate.
      *
      * @param <T> the binary predicate input types
      * @param right the right side object of the comparison.
-     * @return UnaryPredicate
+     * @return Predicate
      */
-    public static <T extends Comparable<?>> UnaryPredicate<T> instance(T right) {
+    public static <T extends Comparable<?>> Predicate<T> instance(T right) {
         return RightBoundPredicate.bind(new IsLessThanOrEqual<T>(), right);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsNotEquivalent.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsNotEquivalent.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsNotEquivalent.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsNotEquivalent.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.Comparator;
 
 import org.apache.commons.functor.BinaryPredicate;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.functor.adapter.RightBoundPredicate;
 import org.apache.commons.lang3.Validate;
 
@@ -133,13 +133,13 @@ public final class IsNotEquivalent<T> im
     }
 
     /**
-     * Get an IsNotEquivalent UnaryPredicate.
+     * Get an IsNotEquivalent Predicate.
      *
      * @param <T> the binary predicate input types
-     * @param right Comparable against which UnaryPredicate arguments will be compared.
-     * @return UnaryPredicate
+     * @param right Comparable against which Predicate arguments will be compared.
+     * @return Predicate
      */
-    public static <T extends Comparable<?>> UnaryPredicate<T> instance(T right) {
+    public static <T extends Comparable<?>> Predicate<T> instance(T right) {
         return RightBoundPredicate.bind(instance(), right);
     }
 

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsWithinRange.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsWithinRange.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsWithinRange.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/IsWithinRange.java Tue Jul 30 22:48:02 2013
@@ -17,18 +17,18 @@
 package org.apache.commons.functor.core.comparator;
 
 import java.io.Serializable;
-import org.apache.commons.functor.UnaryPredicate;
+import org.apache.commons.functor.Predicate;
 import org.apache.commons.lang3.Validate;
 
 /**
- * A {@link UnaryPredicate} that tests whether a {@link Comparable} object is
+ * A {@link Predicate} that tests whether a {@link Comparable} object is
  * within a range. The range is defined in the constructor.
  *
  * @since 1.0
  * @param <A> the predicate argument type.
  * @version $Revision$ $Date$
  */
-public class IsWithinRange<A extends Comparable<A>> implements UnaryPredicate<A>, Serializable {
+public class IsWithinRange<A extends Comparable<A>> implements Predicate<A>, Serializable {
     /**
      * serialVersionUID declaration.
      */

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/Max.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/Max.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/Max.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/comparator/Max.java Tue Jul 30 22:48:02 2013
@@ -20,7 +20,7 @@ import java.io.Serializable;
 import java.util.Comparator;
 
 import org.apache.commons.functor.BinaryFunction;
-import org.apache.commons.functor.UnaryFunction;
+import org.apache.commons.functor.Function;
 import org.apache.commons.functor.adapter.RightBoundFunction;
 import org.apache.commons.lang3.Validate;
 
@@ -115,13 +115,13 @@ public final class Max<T> implements Bin
     }
 
     /**
-     * Get a Max UnaryFunction.
+     * Get a Max Function.
      *
      * @param <T> the binary function arguments and return types.
      * @param right the right side argument of the Max function
-     * @return UnaryFunction<T, T>
+     * @return Function<T, T>
      */
-    public static <T extends Comparable<?>> UnaryFunction<T, T> instance(T right) {
+    public static <T extends Comparable<?>> Function<T, T> instance(T right) {
         return RightBoundFunction.bind(new Max<T>(), right);
     }
--- commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RecursiveEvaluation.java (original)
+++ commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RecursiveEvaluation.java Tue Jul 30 22:48:02 2013
@@ -18,47 +18,47 @@ package org.apache.commons.functor.core.
 
 import java.io.Serializable;
 
-import org.apache.commons.functor.Function;
+import org.apache.commons.functor.NullaryFunction;
 import org.apache.commons.lang3.Validate;
 
 /**
- * Tail recursion for {@link Function functions}. If the {@link Function}
+ * Tail recursion for {@link NullaryFunction functions}. If the {@link NullaryFunction}
  * returns another function of type <code>functionType</code>, that function
  * is executed. Functions are executed until a non function value or a
  * function of a type other than that expected is returned.
  */
-public class RecursiveEvaluation implements Function<Object>, Serializable {
+public class RecursiveEvaluation implements NullaryFunction<Object>, Serializable {
     /**
      * serialVersionUID declaration.
      */
     private static final long serialVersionUID = -7992078213921938619L;
     /**
      * The initial recursive Function type.
      */
     private final Class<?> functionType;
     /**
      * The initial, potentially recursive Function.
      */
-    private Function<?> function;
+    private NullaryFunction<?> function;
 
     /**
      * Create a new RecursiveEvaluation. Recursion will continue while the
      * returned value is of the same runtime class as <code>function</code>.
      * @param function initial, potentially recursive Function
      */
-    public RecursiveEvaluation(Function<?> function) {
+    public RecursiveEvaluation(NullaryFunction<?> function) {
         this(function, getClass(function));
     }
 
     /**
      * Create a new RecursiveEvaluation.
      * @param function initial, potentially recursive Function
      * @param functionType as long as result is an instance, keep processing.
      */
-    public RecursiveEvaluation(Function<?> function, Class<?> functionType) {
-        Validate.notNull(function, "Function argument was null");
-        if (!Function.class.isAssignableFrom(functionType)) {
-            throw new IllegalArgumentException(Function.class + " is not assignable from " + functionType);
+    public RecursiveEvaluation(NullaryFunction<?> function, Class<?> functionType) {
+        Validate.notNull(function, "NullaryFunction argument was null");
+        if (!NullaryFunction.class.isAssignableFrom(functionType)) {
+            throw new IllegalArgumentException(NullaryFunction.class + " is not assignable from " + functionType);
         }
         this.function = function;
         this.functionType = Validate.notNull(functionType, "FunctionType argument was null");
@@ -74,7 +74,7 @@ public class RecursiveEvaluation impleme
         while (true) {
             result = function.evaluate();
             if (functionType.isInstance(result)) {
-                function = (Function<?>) result;
+                function = (NullaryFunction<?>) result;
                 continue;
             } else {
                 break;
@@ -118,7 +118,7 @@ public class RecursiveEvaluation impleme
      * @param f Object to check
      * @return Class found
      */
-    private static Class<?> getClass(Function<?> f) {
+    private static Class<?> getClass(NullaryFunction<?> f) {
         return f == null ? null : f.getClass();
     }
 }
@@ -18,47 +18,47 @@ package org.apache.commons.functor.core.
     private static final long serialVersionUID = -7992078213921938619L;
     /**
-     * The initial recursive Function type.
+     * The initial recursive NullaryFunction type.
      */
     private final Class<?> functionType;
@@ -18,47 +18,47 @@ package org.apache.commons.functor.core.
     private final Class<?> functionType;
     /**
-     * The initial, potentially recursive Function.
+     * The initial, potentially recursive NullaryFunction.
      */
@@ -18,47 +18,47 @@ package org.apache.commons.functor.core.
      * Create a new RecursiveEvaluation. Recursion will continue while the
      * returned value is of the same runtime class as <code>function</code>.
-     * @param function initial, potentially recursive Function
+     * @param function initial, potentially recursive NullaryFunction
      */
@@ -18,47 +18,47 @@ package org.apache.commons.functor.core.
     /**
      * Create a new RecursiveEvaluation.
-     * @param function initial, potentially recursive Function
+     * @param function initial, potentially recursive NullaryFunction
      * @param functionType as long as result is an instance, keep processing.
      */

Modified: commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RemoveMatching.java
URL: http://svn.apache.org/viewvc/commons/proper/functor/trunk/core/src/main/java/org/apache/commons/functor/core/algorithm/RemoveMatching.java?rev=1508677&r1=1508676&r2=1508677&view=diff
==============================================================================